# API Reference

This is a reference API class listing, and modules.

## Top-level functions

```{eval-rst}
.. currentmodule:: intake
.. autosummary::
   open_thredds_cat
   open_thredds_merged

```

## Catalog & Source Objects

```{eval-rst}
.. currentmodule:: intake_thredds
.. automodule:: intake_thredds.cat
    :members:


.. automodule:: intake_thredds.source
    :members:

```
